Configurations.
Structs
- Block
Config - Stable parameters for the whole block across processing runs.
- Block
Info - Contextual block information.
- Execution
Settings - Execution settings for handling messages.
- Page
Costs - Memory operations costs.
Constants
- TESTS_
MAX_ PAGES_ NUMBER - Number of max pages number to use it in tests.